# Graphical User Interface

Use desktop shortcut or run:

> toolmateai

![gui_screenshot](https://github.com/user-attachments/assets/b174da1c-da62-43ea-b3d7-c52d09fd4283)

Support user confirmation for code execution:

![user_confirmation](https://github.com/user-attachments/assets/3172aa25-9def-4c41-b896-9d18a2a18334)

Support system tray:

![gui_screenshot2](https://github.com/user-attachments/assets/a9f09a44-f078-44b3-9922-e64b3b59bef7)

Select `Edit Configurations` from system tray to change settings:

![setup](https://github.com/user-attachments/assets/731a897f-464b-4b79-b3b8-95de69c5080d)
